---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: ''
assignees: ''

---

### Is your feature request related to a problem? Please describe.
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

### Feature Description
A clear and concise description of the feature you want or need.

### Describe Alternatives
A clear and concise description of any alternative solutions or features you've considered. Are there examples you could link us to?

### Additional context
Add any other context here.

### Priority
Please help us better understand this feature request by choosing a priority from the following options:
[Nice to Have, Really Want, Must Have, Blocker]
